@@ -1,7 +1,9 @@
 mod kinematic;
-mod staticbody;
 mod sensor;
+mod staticbody;
+mod raycast;
 
 pub use kinematic::*;
+pub use sensor::*;
 pub use staticbody::*;
-pub use sensor::*;
\ No newline at end of file
+pub use raycast::*;
